==> hunspell-dict-ko_0.7.92.orig.tar.gz: hunspell-dict-ko-0.7.92/LICENSE.md <==
# License information

Copyright (C) 2008-2019 hunspell-dict-ko contributors
Copyright (C) 2017-2019 National Institute of Korean Language

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

## Details

### MPL-1.1/GPL-2.0/LGPL-2.1 tri-license

The generating source codes and some word data files
(data/entries/*-legacy.yaml) are distributed under the
MPL-1.1/GPL-2.0/LGPL-2.1 tri-license. See LICENSE.MPL-1.1, LICENSE.GPL-2 and
LICENSE.LGPL-2.1 for terms.

### CC-BY-SA-4.0

The most word data files (dict-ko-builtin.yaml and data/entries/*.yaml without
'-legacy') are distributed under the Creative Commons Attribution-ShareAlike
4.0 International license.

### original licenses: CC-BY-SA-2.0-KR and CC-BY-4.0

The words data imported from dictionaries by National Institute of Korean
Language and other words are distributed under the Creative Commons
Attribution-ShareAlike 2.0 Korea license. See LICENSE.CC-BY-SA-2.0-KR for
terms. Some word data, whose licenses are explicitly specified as "CC BY 4.0",
from old version of hunspell-dict-ko project, are distributed under the
Creative Commons Attribution 4.0 International license. See LICENSE.CC-BY-4.0
for terms.

### GPL-3.0 for the combined work

The combined dict-ko-data.yaml in the source code and the built files (ko.aff
and ko.dic) are licensed under the GPL version 3. See LICENSE.GPL-3.0 for
terms.

Works under CC BY 4.0 and CC BY-SA 2.0 KR can be adapted under CC BY-SA 4.0.
And CC BY-SA 4.0 declares the GPL version 3 as an one-way compatible license.
Therefore, The combined dictionary is licensed under the GPL version 3. See
https://creativecommons.org/share-your-work/licensing-considerations/compatible-licenses

==> hunspell-dict-ko_0.7.94.orig.tar.gz: hunspell-dict-ko-0.7.94/LICENSE.md <==
# License information

Copyright (C) 2008-2019 hunspell-dict-ko contributors
Copyright (C) 2017-2019 National Institute of Korean Language

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

## Details

### MPL-1.1/GPL-2.0/LGPL-2.1 tri-license

The generating source codes and some word data files
(data/entries/*-legacy.yaml) are distributed under the
MPL-1.1/GPL-2.0/LGPL-2.1 tri-license. See LICENSE.MPL-1.1, LICENSE.GPL-2 and
LICENSE.LGPL-2.1 for terms.

### CC-BY-SA-4.0

The most word data files (dict-ko-builtin.yaml and data/entries/*.yaml without
'-legacy') are distributed under the Creative Commons Attribution-ShareAlike
4.0 International license.

### original licenses: CC-BY-SA-2.0-KR and CC-BY-4.0

The words data imported from dictionaries by National Institute of Korean
Language and other words are distributed under the Creative Commons
Attribution-ShareAlike 2.0 Korea license. See LICENSE.CC-BY-SA-2.0-KR for
terms. Some word data, whose licenses are explicitly specified as "CC BY 4.0",
from old version of hunspell-dict-ko project, are distributed under the
Creative Commons Attribution 4.0 International license. See LICENSE.CC-BY-4.0
for terms.

### GPL-3.0 for the combined work

The combined dict-ko-data.yaml in the source code and the built files (ko.aff
and ko.dic) are licensed under the GPL version 3. See LICENSE.GPL-3.0 for
terms.

Works under CC BY 4.0 and CC BY-SA 2.0 KR can be adapted under CC BY-SA 4.0.
And CC BY-SA 4.0 declares the GPL version 3 as an one-way compatible license.
Therefore, The combined dictionary is licensed under the GPL version 3. See
https://creativecommons.org/share-your-work/licensing-considerations/compatible-licenses

### Note about GPL Compatibility

This dictionary can also be used with GPLv3 incompatible softwares.

The executable program and a hunspell dictionary are considered as seperate
works, therefore their licenses do not need to be compatible. See
https://lwn.net/Articles/481386/ and
https://bz.apache.org/ooo/show_bug.cgi?id=65039#c16 for details.
